@@ -341,7 +341,6 @@ scoreGxG <- function(mat.snp, model=c("additive", "dominant", "recessive"), gene
 	kid <- out$kid
 	mat.ids <- out$mat.comb
 	cn <- if(is.null(colnames(mat.snp))) paste("SNP", 1:ncol(mat.snp), sep="") else colnames(mat.snp)
-	rm(mat.snp, out)
 	if(is.null(genes))
 		combs <- allCombs(ncol(kid))
 	else{
@@ -354,7 +353,12 @@ scoreGxG <- function(mat.snp, model=c("additive", "dominant", "recessive"), gene
 	}
 	n.combs <- nrow(combs)
 	int <- unique(c(seq.int(1, n.combs, size), n.combs + 1))
-	betaFun <- match.fun(paste("scoreBeta", type, sep=""))
+	if(type == "Add")
+		betaFun <- scoreBetaAdd
+	if(type == "Dom")
+		betaFun <- scoreBetaDom
+	if(type == "Rec")
+		betaFun <- scoreBetaRec
 	beta <- v <- rep.int(NA, n.combs)
 	for(i in 1:(length(int)-1)){
 		tmp <- betaFun(mat.ids, kid, combs[int[i]:(int[i+1]-1),])
