@@ -1,5 +1,8 @@
+# Removed colTDT. Updated version in colTDTnew.R.
+
+
 tdt <- function(snp, model=c("additive", "dominant", "recessive")){
-	require(survival)
+	requireNamespace("survival")
 	n <- length(snp)
 	if(n%%3 != 0)
 		stop("snp has a length not dividable by 3.")
@@ -35,14 +38,14 @@ tdt <- function(snp, model=c("additive", "dominant", "recessive")){
 	stat <- (coef/se)^2
 	conf <- exp(coef + c(-1, 1) * qnorm(0.975) * se)
 	out <- list(coef=coef, se=se, stat=stat, pval= 1 - pchisq(stat, 1),
-		OR=exp(coef), lowerOR=conf[1], upperOR=conf[2], ia=FALSE, type=type)  
+		RR=exp(coef), lowerRR=conf[1], upperRR=conf[2], ia=FALSE, type=type)  
 	class(out) <- "tdt"
 	out
 }
 
 print.tdt <- function(x, digits=4, ...){
 	pval <- format.pval(x$pval, digits=digits)
-	out <- data.frame(Coef=x$coef, OR=x$OR, Lower=x$lowerOR, Upper=x$upperOR, 
+	out <- data.frame(Coef=x$coef, RR=x$RR, Lower=x$lowerRR, Upper=x$upperRR, 
 		SE=x$se, Statistic=x$stat, "p-Value"=pval, check.names=FALSE)
 	if(length(x$coef)==1)
 		rownames(out) <- ""
@@ -67,7 +70,7 @@ tdt2way <- function(...)
 	cat("tdt2way has been renamed to tdtGxG. So please use tdtGxG instead.")
 
 tdtGxG <- function(snp1, snp2, test=c("epistatic", "lrt", "full", "screen"), model=c("additive", "dominant", "recessive")){
-	require(survival)
+	requireNamespace("survival")
 	n1 <- length(snp1)
 	n2 <- length(snp2)
 	if(n1 != n2)
@@ -161,28 +164,12 @@ tdtGxG <- function(snp1, snp2, test=c("epistatic", "lrt", "full", "screen"), mod
 		upper <- exp(coef + qnorm(0.975) * se)
 	}
 	out <- list(coef=coef, se=se, stat=stat, pval= pval,
-		OR=exp(coef), lowerOR=lower, upperOR=upper, ia=TRUE, type=type)  
+		RR=exp(coef), lowerRR=lower, upperRR=upper, ia=TRUE, type=type)  
 	class(out) <- "tdt"
 	out
 
 }
 
-	
-
-colTDT <- function(mat.snp, model=c("additive", "dominant", "recessive"), size=50){
-	if(!is.matrix(mat.snp))
-		stop("mat.snp has to be a matrix.")
-	if(nrow(mat.snp) %% 3 != 0)
-		stop("mat.snp does not seem to contain trio data, as its number of rows is\n",
-			"not dividable by 3.")
-	if(is.null(rownames(mat.snp)))
-		stop("mat.snp does not seem to be a matrix in genotype format,\n",
-			"as the names of the rows are missing.")
-	if(any(!mat.snp %in% c(0, 1, 2, NA)))
-		stop("The values in mat.snp must be 0, 1, and 2.")
-	type <- match.arg(model)
-	fastTDT(mat.snp, type, size=size)
-}
 
 colTDT2way <- function(...){
 	cat("colTDT2way has been renamed to colGxG. So please use colGxG instead.\n")
@@ -190,7 +177,7 @@ colTDT2way <- function(...){
 
 colGxG <- function(mat.snp, test=c("epistatic", "lrt", "full", "screen"), genes=NULL, maf=FALSE,
 		model=c("additive", "dominant", "recessive")){
-	require(survival)
+	requireNamespace("survival")
 	if(!is.matrix(mat.snp))
 		stop("mat.snp has to be a matrix.")
 	if(nrow(mat.snp) %% 3 != 0)
@@ -294,8 +281,8 @@ colGxG <- function(mat.snp, test=c("epistatic", "lrt", "full", "screen"), genes=
 	}
 	else
 		mat.maf <- NULL
-	out <- list(coef=coef, se=se, stat=stat, pval=pval, OR=exp(coef), 
-		lowerOR=lower, upperOR=upper, ia=TRUE, type=type, add=add, genes=genes, maf=valMAF,
+	out <- list(coef=coef, se=se, stat=stat, pval=pval, RR=exp(coef), 
+		lowerRR=lower, upperRR=upper, ia=TRUE, type=type, add=add, genes=genes, maf=valMAF,
 		matMAF=mat.maf) 
 	class(out) <- "colTDT"
 	out	
@@ -306,14 +293,14 @@ colGxG <- function(mat.snp, test=c("epistatic", "lrt", "full", "screen"), genes=
 print.colTDT <- function(x, top=5, digits=4, ...){
 	pval <- format.pval(x$pval, digits=digits)
 	if(x$ia){
-		out <- data.frame(Coef=x$coef, OR=x$OR, Lower=x$lowerOR, Upper=x$upperOR, 
+		out <- data.frame(Coef=x$coef, RR=x$RR, Lower=x$lowerRR, Upper=x$upperRR, 
 			SE=x$se, Statistic=x$stat, "p-Value"=pval,
 			check.names=FALSE, stringsAsFactors=FALSE)
 		cat("      Genotypic TDT for Two-Way Interaction (Using 15 Pseudo Controls)",
 			"\n\n")
 	}
 	else{
-		out <- data.frame(Coef=x$coef, OR=x$OR, Lower=x$lowerOR, Upper=x$upperOR, 
+		out <- data.frame(Coef=x$coef, RR=x$RR, Lower=x$lowerRR, Upper=x$upperRR, 
 			SE=x$se, Statistic=x$stat, "p-Value"=pval, Trios=x$usedTrios,
 			check.names=FALSE, stringsAsFactors=FALSE)
 		if(!is.null(x$pMendelErr))
